@@ -46,55 +46,43 @@ domino.jumpToProjectsWorkingDirectory <- function(projectName) {
   print("Changed working directory to new project's directory.")
 }
 
-
-# Checks whether domino is in the system's path, by running a 'dummy' command. 
-# If the result is an error, domino it's safe to assume that domino is not found
 .is.domino.in.path <- function() {
-  result <- try(
-    system("domino help", ignore.stdout=TRUE, ignore.stderr=TRUE), 
-    silent = TRUE
-    )
-  if(!inherits(result, "try-error") && result != 127) {
-    TRUE
-  } else {
-    FALSE
-  }
+  nzchar(Sys.which("domino")) 
 }
 
 .open.rStudio.login.prompt <- function(message){
   if(Sys.getenv("RSTUDIO") != "1"){
     stop("The system is not running in RStudio")
   }
-  
+
   if(!("tools:rstudio" %in% search())){
     stop("Cannot locate RStudio tools")
   }
-  
+
   toolsEnv <- as.environment("tools:rstudio")
   rStudioLoginPrompt <- get(".rs.askForPassword", envir=toolsEnv)
-  
+
   rStudioLoginPrompt(message)
 }
 
 .domino.login.prompt <- function(){
   passwordPromptMessage <- "Enter your Domino password: "
-  
-  # if not in rstudio env or the prompt function is not found, 
+
+  # if not in rstudio env or the prompt function is not found,
   # the function will fail => fallback to readLine
   password <- try(.open.rStudio.login.prompt(passwordPromptMessage), silent=T)
-  
+
   if(inherits(password, "try-error")){
-    password <- readline("Enter your Domino password: ") 
+    password <- readline("Enter your Domino password: ")
   }
-  
+
   if(password == ""){
     password <- NULL
   }
-  
+
   password
 }
 
 .onAttach <- function(libname, pkgname) {
   domino$command_is_in_the_path <- .is.domino.in.path()
 }
-
